## CHANGELOG

### 0.11.0 - 2020-09-29

 - Improve api.listen error handling

### 0.10.0 - 2020-09-26

 - Improve gcloud pubsub backend

### 0.9.0 - 2020-09-19

 - Improve documentation

 - Create EventsHandler class from broadcaster lib

 - Add support for Google Cloud Platform PubSub service

### 0.8.0 - 2020-09-17

 - Improve specification exposition

 - Fix specification dataclasses

### 0.7.2 - 2020-09-04

 - Improve api.listen logging

### 0.7.1 - 2020-07-23

 - Improve subscriber error handler

### 0.7.0 - 2020-07-11

 - Add support for pubsub protocol

 - Fix api for non-dataclasses messsages

### 0.6.1 - 2020-07-08

 - Update docs

### 0.6.0 - 2020-07-08

 - Expose in http the auto-generated specification

### 0.5.0 - 2020-07-07

 - Refactor api

### 0.4.0 - 2020-07-06

 - Create docs

 - Fix api publish and listen methods

### 0.3.1 - 2020-07-03

 - Support load subscriber as script

### 0.3.0 - 2020-07-03

 - Create subscriber cli

### 0.2.0 - 2020-07-02

 - Create publish and listen methods for api

###  - 2020-07-02

 - Create Api object from asyncapi spec
